<div class="row card-container">
    <div class="thumbnail card">
        <div class="caption">
        {% if title != None %}
            <h3>{{ title }}</h3>
        {% end %}
            <form class="form-{{ type }}" action="{{ action }}" >
                {% for input in inputs %}
                    <div class="form-group">
                        {% if input[0] == 'checkbox' %}
                        <div class="checkbox">
                            <label  for="{{ input[1] }}" style="margin-left: 25px;">
                                <input style="margin-top: -8px;" name='{{ input[1] }}' type="{{ input[0] }}" class="form-control" id="id-{{ input[1] }}" value="{{ input[2] }}" placeholder="{{  input[1] }}'s value "> {{ input[1][0].upper() + input[1][1:] }}
                                    
                            </label>
                        </div>
                        {% elif input[0] == 'file' %}
                            <label for="{{ input[1] }}" style="margin-left: 14px;">
                                {{ input[1][0].upper() + input[1][1:]  }}
                            </label>
                            <input style='margin-left: 25px; width: initial' name='{{ input[1] }}' type="{{ input[0] }}"  id="id-{{ input[1] }}" value="{{ input[2] }}" />
                        {% elif input[0] == 'submit' %}
                            <button type="submit" class="btn btn-default" >{{ input[2] }}</button>

                        {% else %}
                            <label for="{{ input[1] }}" style="margin-left: 14px;">
                                {{ input[1][0].upper() + input[1][1:]  }}
                            </label>
                            <input style='margin-left: 25px; width: initial' name='{{ input[1] }}' type="{{ input[0] }}" class="form-control" id="id-{{ input[1] }}" value="{{ input[2] }}" placeholder="{{  input[1] }}'s value "/>                        
                        
                        {% end %}
                    </div>
                {% end %}
            </form >

        </div>
    </div> 
</div>


