<div class="table" style="margin:10px;">
    <table class="table table-{{ type }}">
      {% if title != None %}
        <h3>{{ title }}</h3>
      {% end %}
      <thead>
        <tr>
        {% for head in headers %}
          <th>{{ head }}</th>
        {% end %}
        </tr>
      </thead>
      <tbody>
        {% for row in items %}
        <tr>
          {% for item in row %}
            <th>{{ item }}</th>
          {% end %}
        </tr>
        {% end %}
      </tbody>
    </table>
</div>